import React, {Component} from 'react';
import IngredientList from './ingredients-list';
import AddIngredients from './add-ingredients';

class AddRecipeForm extends Component {
  static defaultProps = {
    onNewRecipe() {}
  }

  constructor() {
    super();
    this.state = {
      ingredients: []
    };
    this.doSubmitRecipe = this.doSubmitRecipe.bind(this);
    this.doAddIngredient = this.doAddIngredient.bind(this);
    this.doClearIngredientList = this.doClearIngredientList.bind(this);
  }

  doSubmitRecipe(event) {
    event.preventDefault();
    const {_recipeName} = this.refs;
    const {onNewRecipe} = this.props;
    const {ingredients} = this.state;
    onNewRecipe(_recipeName.value, ingredients);
    this.setState({
      ingredients: []
    });
    _recipeName.value = '';
    _recipeName.focus();
  }

  doAddIngredient(ingredient) {
    const {ingredients} = this.state;
    this.setState({
      ingredients: [
        ...ingredients,
        ingredient
      ]
    });
  }

  doClearIngredientList() {
    this.setState({
      ingredients: []
    });
  }

  render() {
    const {ingredients} = this.state;
    return (
      <div>
        <h3>Add Recipe</h3>
        <form onSubmit={this.doSubmitRecipe}>
          <input className="form-control" ref="_recipeName" type="text" placeholder="Recipe name" required/>
          <div className="card mt-2">
            <div className="card-body">
              {
                (ingredients.length !== 0)
                  ? <IngredientList list={ingredients}/>
                  : <p>No ingredients</p>
              }
              <AddIngredients onNewIngredient={this.doAddIngredient}
                onClearIngredientList={this.doClearIngredientList}/>
            </div>
          </div>
          {/* TODO: add AddInstructions Element */}
          <button className="btn btn-primary mt-2">Add Recipe</button>
        </form>
      </div>
    );
  }
}

export default AddRecipeForm;
